@@ -7,14 +7,14 @@ import yaml
 
 from .db import DB
 
-__version__ = "0.5.4"
+__version__ = "0.5.5"
 
 logging.basicConfig(format="%(asctime)s: %(message)s",
                     level=logging.INFO)
 
 _CONFIG = {
-    "api_id": "",
-    "api_hash": "",
+    "api_id": os.getenv("API_ID", ""),
+    "api_hash": os.getenv("API_HASH", ""),
     "group": "",
     "download_avatars": True,
     "avatar_size": [64, 64],
@@ -83,8 +83,6 @@ def main():
                    dest="template", help="path to the template file")
     b.add_argument("--rss-template", action="store", type=str, default=None,
                    dest="rss_template", help="path to the rss template file")
-    b.add_argument("-o", "--output", action="store", type=str, default="site",
-                   dest="output", help="path to the output directory")
     b.add_argument("--symlink", action="store_true", dest="symlink",
                    help="symlink media and other static files instead of copying")
 
@@ -143,10 +141,11 @@ def main():
         from .build import Build
 
         logging.info("building site")
-        b = Build(get_config(args.config), DB(args.data), args.symlink)
+        config = get_config(args.config)
+        b = Build(config, DB(args.data), args.symlink)
         b.load_template(args.template)
         if args.rss_template:
             b.load_rss_template(args.rss_template)
         b.build()
 
-        logging.info("published to directory '{}'".format(args.output))
+        logging.info("published to directory '{}'".format(config["publish_dir"]))
